@@ -37,7 +37,6 @@
 #include <gio/gunixinputstream.h>
 
 #define BUS_ADDRESS_FILENO (STDERR_FILENO + 1)
-#define DBUS_DAEMON BINDIR "/dbus-daemon"
 
 typedef struct
 {
@@ -90,14 +89,14 @@ static gboolean
 spawn_bus (State        *state,
            GCancellable *cancellable)
 {
-        GPtrArray           *arguments;
-        GSubprocessLauncher *launcher;
-        GSubprocess         *subprocess;
-        GInputStream        *input_stream;
-        GDataInputStream    *data_stream;
+        GPtrArray           *arguments = NULL;
+        GSubprocessLauncher *launcher = NULL;
+        GSubprocess         *subprocess = NULL;
+        GInputStream        *input_stream = NULL;
+        GDataInputStream    *data_stream = NULL;
         GError              *error = NULL;
-        char                *bus_address_fd_string;
-        char                *bus_address;
+        char                *bus_address_fd_string = NULL;
+        char                *bus_address = NULL;
         gsize                bus_address_size;
 
         gboolean  is_running = FALSE;
@@ -119,7 +118,7 @@ spawn_bus (State        *state,
 
         bus_address_fd_string = g_strdup_printf ("%d", BUS_ADDRESS_FILENO);
 
-        g_ptr_array_add (arguments, DBUS_DAEMON);
+        g_ptr_array_add (arguments, "dbus-daemon");
 
         g_ptr_array_add (arguments, "--print-address");
         g_ptr_array_add (arguments, bus_address_fd_string);
@@ -134,7 +133,7 @@ spawn_bus (State        *state,
         g_ptr_array_free (arguments, TRUE);
 
         if (subprocess == NULL) {
-                g_debug ("could not start X server: %s", error->message);
+                g_debug ("could not start dbus-daemon: %s", error->message);
                 goto out;
         }
 
@@ -214,12 +213,12 @@ static gboolean
 spawn_session (State        *state,
                GCancellable *cancellable)
 {
-        GSubprocessLauncher *launcher;
+        GSubprocessLauncher *launcher = NULL;
         GSubprocess         *subprocess = NULL;
         GError              *error = NULL;
         gboolean             is_running = FALSE;
         int                  ret;
-        char               **argv;
+        char               **argv = NULL;
 
         g_debug ("Running wayland session");
 
@@ -287,7 +286,7 @@ static gboolean
 register_display (State        *state,
                   GCancellable *cancellable)
 {
-        GdmDBusManager  *manager;
+        GdmDBusManager  *manager = NULL;
         GError          *error = NULL;
         gboolean         registered = FALSE;
         GVariantBuilder  details;
@@ -358,8 +357,8 @@ int
 main (int    argc,
       char **argv)
 {
-        State           *state;
-        GOptionContext  *context;
+        State           *state = NULL;
+        GOptionContext  *context = NULL;
         static char    **args = NULL;
         gboolean         debug = FALSE;
         gboolean         ret;
